==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/documents/classes/backup/BackupCollection.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array("_a0c574277fd3c2720a40f6e1" . "ba4e33f5" => base64_decode("U0VMRUNUIGlkIEZST0" . "0gYmFja3VwX3Nlcmll" . "cw=="));





class BackupCollection implements IteratorAggregate
{
    protected $items = [];
    
    
    
    
    public function Load($_82eb4a68a9db5431865bed0c5837de30 = true)
    {
        global $db;
        $_189840d11056515e52402d1412a0b6e4 = $db->query($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_a0c574277fd3c2720a40f6e1" . "ba4e33f5"]);
        while ($_b8cfc2e06d9d1fec1893ea4a054002bf = $_189840d11056515e52402d1412a0b6e4->fetchRow()) {
            $_20eedf73e25dd0dfcc2236fcba14aff4 = new BackupSingleSeries();
            try {
                $_20eedf73e25dd0dfcc2236fcba14aff4->Load($_b8cfc2e06d9d1fec1893ea4a054002bf[0]);
                $_b3332fc4b021e81f555e2958f9534536 = $_20eedf73e25dd0dfcc2236fcba14aff4->GetSeriesFolders();
                if (!empty($_b3332fc4b021e81f555e2958f9534536)) {
                    $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                } elseif (empty($_b3332fc4b021e81f555e2958f9534536) && $_82eb4a68a9db5431865bed0c5837de30) {
                    $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                }
            } catch (BackupException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
                $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                $_20eedf73e25dd0dfcc2236fcba14aff4->eh->ProcessError($_fe441aa3ef350bfb1a1a1ad8520dd530->getCode(), $_fe441aa3ef350bfb1a1a1ad8520dd530->getData());
            }
        }
    }
    
    
    public function getIterator()
    {
        return new ArrayIterator($this->items);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/documents/classes/backup/BackupCollection.php <==
<?php
$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] ?: array()) + array("_a0c574277fd3" . "c2720a40f6e1b" . "a4e33f5" => base64_decode("U0VMRUNUIGlkIEZ" . "ST00gYmFja3VwX3" . "Nlcmllcw=="));





class BackupCollection implements IteratorAggregate
{
    protected $items = [];
    
    
    
    
    public function Load($_82eb4a68a9db5431865bed0c5837de30 = true)
    {
        global $db;
        $_189840d11056515e52402d1412a0b6e4 = $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_a0c574277fd3c2720a40f" . "6e1ba4e33f5"]);
        while ($_b8cfc2e06d9d1fec1893ea4a054002bf = $_189840d11056515e52402d1412a0b6e4->fetchRow()) {
            $_20eedf73e25dd0dfcc2236fcba14aff4 = new BackupSingleSeries();
            try {
                $_20eedf73e25dd0dfcc2236fcba14aff4->Load($_b8cfc2e06d9d1fec1893ea4a054002bf[0]);
                $_b3332fc4b021e81f555e2958f9534536 = $_20eedf73e25dd0dfcc2236fcba14aff4->GetSeriesFolders();
                if (!empty($_b3332fc4b021e81f555e2958f9534536)) {
                    $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                } elseif (empty($_b3332fc4b021e81f555e2958f9534536) && $_82eb4a68a9db5431865bed0c5837de30) {
                    $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                }
            } catch (BackupException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
                $this->items[] = $_20eedf73e25dd0dfcc2236fcba14aff4;
                $_20eedf73e25dd0dfcc2236fcba14aff4->eh->ProcessError($_fe441aa3ef350bfb1a1a1ad8520dd530->getCode(), $_fe441aa3ef350bfb1a1a1ad8520dd530->getData());
            }
        }
    }
    
    
    public function getIterator()
    {
        return new ArrayIterator($this->items);
    }
}
